@@ -1,13 +1,11 @@
 from django.db import models
-from wagtail.snippets.models import register_snippet
 from wagtail.search import index
 from wagtail.admin.edit_handlers import FieldPanel
 from wagtail.documents.models import Document
 from wagtail.documents.edit_handlers import DocumentChooserPanel
 
 
-@register_snippet
-class IconSnippet(index.Indexed, models.Model):
+class AIconSnippet(index.Indexed, models.Model):
     key = models.CharField(max_length=255)
     light = models.ForeignKey(
         Document,
@@ -39,3 +37,5 @@ class IconSnippet(index.Indexed, models.Model):
 
     class Meta:
         verbose_name = "Icon"
+        abstract = True
+        app_label = 'cms'
